MSEHCalibration

Struct MSEHCalibration 

#[repr(C)]
pub struct MSEHCalibration {
Show 20 fields pub type_: [c_char; 30], pub begintime: nstime_t, pub endtime: nstime_t, pub steps: c_int, pub firstpulsepositive: c_int, pub alternatesign: c_int, pub trigger: [c_char; 30], pub continued: c_int, pub amplitude: f64, pub inputunits: [c_char; 30], pub amplituderange: [c_char; 30], pub duration: f64, pub sineperiod: f64, pub stepbetween: f64, pub inputchannel: [c_char; 30], pub refamplitude: f64, pub coupling: [c_char; 30], pub rolloff: [c_char; 30], pub noise: [c_char; 30], pub next: *mut MSEHCalibration,
}
@brief Container for calibration parameters for use in extra headers

Actual values are optional, with special values indicating an unset state.

@see mseh_add_calibration

Fields

type_: [c_char; 30]

< Calibration type (e.g. “STEP”, “SINE”, “PSEUDORANDOM”), zero length = not included

begintime: nstime_t

< Begin time, NSTUNSET = not included

endtime: nstime_t

< End time, NSTUNSET = not included

steps: c_int

< Number of step calibrations, -1 = not included

firstpulsepositive: c_int

< Boolean, step cal. first pulse, -1 = not included

alternatesign: c_int

< Boolean, step cal. alt. sign, -1 = not included

trigger: [c_char; 30]

< Trigger, e.g. AUTOMATIC or MANUAL, zero length = not included

continued: c_int

< Boolean, continued from prev. record, -1 = not included

amplitude: f64

< Amp. of calibration signal, 0.0 = not included

inputunits: [c_char; 30]

< Units of input (e.g. volts, amps), zero length = not included

amplituderange: [c_char; 30]

< E.g PEAKTOPTEAK, ZEROTOPEAK, RMS, RANDOM, zero length = not included

duration: f64

< Duration in seconds, 0.0 = not included

sineperiod: f64

< Period of sine, 0.0 = not included

stepbetween: f64

< Interval bewteen steps, 0.0 = not included

inputchannel: [c_char; 30]

< Channel of input, zero length = not included

refamplitude: f64

< Reference amplitude, 0.0 = not included

coupling: [c_char; 30]

< Coupling, e.g. Resistive, Capacitive, zero length = not included

rolloff: [c_char; 30]

< Rolloff of filters, zero length = not included

noise: [c_char; 30]

< Noise for PR cals, e.g. White or Red, zero length = not included

next: *mut MSEHCalibration

< Pointer to next, NULL if none