MSEHTimingException

Struct MSEHTimingException 

#[repr(C)]
pub struct MSEHTimingException { pub time: nstime_t, pub vcocorrection: f32, pub usec: c_int, pub receptionquality: c_int, pub count: u32, pub type_: [c_char; 16], pub clockstatus: [c_char; 128], }
@brief Container for timing exception parameters for use in extra headers

Actual values are optional, with special values indicating an unset state.

@see mseh_add_timing_exception

Fields

time: nstime_t

< Time of exception, NSTUNSET = not included

vcocorrection: f32

< VCO correction, from 0 to 100%, <0 = not included

usec: c_int

< [DEPRECATED] microsecond time offset, 0 = not included

receptionquality: c_int

< Reception quality, 0 to 100% clock accurracy, <0 = not included

count: u32

< The count thereof, 0 = not included

type_: [c_char; 16]

< E.g. “MISSING” or “UNEXPECTED”, zero length = not included

clockstatus: [c_char; 128]

< Description of clock-specific parameters, zero length = not included